abstractions/abstractions library
Classes
- AbstractDocument
- AritmeticFieldBasedModifier
- ComparableFilter
- This filter is used to filter in fields that are comparable.
- ComparableInListFilter
- This filter is used to filter in fields that are iterables and contain comparable values.
- FieldBasedFilter
- This filter is used to filter in fields with any value except null.
- FieldBasedModifier
- Filter
- The base definition for all filters.
- FilterOperation
- IdProperty
- ListFieldBasedModifier
- LogicalFilter
- This filter is used to create decision logic with anothers filters.
- Modifier
- SelectorProperty
- SortingAwareFilter
- This filter is used to filter in fields that are sorteable.
- ValidatorProperty
Exceptions / Errors
- CollQLException
- Base class for all CollQL exceptions.
- FilterException
- Exception thrown during find operations due to invalid filter expression.