- Mixed-in types
-
- Implementers
Properties
-
entries
→ Iterable<MapEntry<String, dynamic>>
-
The map entries of this Map.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ dynamic
-
Get the document ID.
no setter
-
idPath
↔ String
-
Define the path to the document ID.
getter/setter pair
-
isEmpty
→ bool
-
Whether there is no key/value pair in the map.
no setterinherited
-
isNotEmpty
→ bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
-
keys
→ Iterable<String>
-
The keys of this Map.
no setteroverride
-
length
→ int
-
The number of key/value pairs in the map.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Iterable
-
The values of this Map.
no setterinherited
Methods
-
add(String selector, dynamic newValue)
→ void
-
Add a new value to the document at the specified path selector.
-
addAll(Map<String, dynamic> other)
→ void
-
Adds all key/value pairs of
other to this map.
inherited
-
addEntries(Iterable<MapEntry<String, dynamic>> newEntries)
→ void
-
Adds all key/value pairs of
newEntries to this map.
inherited
-
cast<RK, RV>()
→ Map<RK, RV>
-
Provides a view of this map as having
RK keys and RV instances,
if necessary.
inherited
-
clear()
→ void
-
Removes all entries from the map.
override
-
containsKey(Object? key)
→ bool
-
Whether this map contains the given
key.
inherited
-
containsValue(Object? value)
→ bool
-
Whether this map contains the given
value.
inherited
-
copy(String fromSelector, String toSelector)
→ void
-
Copy a value from one path to another in the document.
-
diff(String selector, Document doc)
→ List
-
-
forEach(void action(String key, dynamic value))
→ void
-
Applies
action to each key/value pair of the map.
inherited
-
generateId()
→ void
-
Generate and return a new ID for the document.
-
get<T>(String selector, {T? defaultValue})
→ T?
-
-
getType(String selector)
→ String
-
Get the type of the value at the specified path selector.
-
map<K2, V2>(MapEntry<K2, V2> transform(String key, dynamic value))
→ Map<K2, V2>
-
Returns a new map where all entries of this map are transformed by
the given
convert function.
inherited
-
mergePatch(String selector, Document patch)
→ void
-
-
move(String fromSelector, String toSelector)
→ void
-
Move a value from one path to another in the document.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(String key, dynamic ifAbsent())
→ dynamic
-
Look up the value of
key, or add a new entry if it isn't there.
inherited
-
remove(Object? selector)
→ void
-
Remove a value from the document at the specified path selector.
override
-
removeWhere(bool test(String key, dynamic value))
→ void
-
Removes all entries of this map that satisfy the given
test.
inherited
-
set(String selector, dynamic newValue)
→ void
-
Set a value in the document at the specified path selector.
-
sizeInfo()
→ ({int bytes, int paths})
-
Get size information about the document.
-
toJsonMap()
→ Map<String, dynamic>
-
Convert the document to a JSON string.
-
toJsonString()
→ String
-
Convert the document to a JSON string.
-
toMap()
→ Map<String, dynamic>
-
Convert the document to Dart Map.
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?})
→ dynamic
-
Updates the value for the provided
key.
inherited
-
updateAll(dynamic update(String key, dynamic value))
→ void
-
Updates all values.
inherited
-
validate(String selector, String reference)
→ bool
-
Validate a value in the document at the specified path selector.
Operators
-
operator ==(Object other)
→ bool
-
The equality operator.
inherited
-
operator [](Object? selector)
→ dynamic
-
Get a value from the document at the specified path selector.
override
-
operator []=(String selector, dynamic newValue)
→ void
-
Associates the
key with the given value.
override