add method

void add(
  1. String selector,
  2. dynamic newValue
)

Add a new value to the document at the specified path selector.

This is a convenience alias method that calls set with the same selector and value.

Implementation

void add(String selector, dynamic newValue) => set(selector, newValue);