validate abstract method

bool validate(
  1. String selector,
  2. String reference
)

Validate a value in the document at the specified path selector.

reference is the information used to validate, such as a JSON schema. It depends on the implementation of the document.

Implementation

bool validate(String selector, String reference);