CollQLException class

Base class for all CollQL exceptions.

Implemented types
Implementers

Constructors

CollQLException(String message, {StackTrace? stackTrace, dynamic cause})

Properties

cause → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited