ComparableFilter class abstract

This filter is used to filter in fields that are comparable.

Inheritance
Implementers
Available extensions

Constructors

ComparableFilter(String field, Comparable value)

Properties

field String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
name String

Available on Filter, provided by the FilterExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
finalinherited

Methods

and(Filter filter) Filter
inherited
apply(Document doc) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Filter
inherited
or(Filter filter) Filter
inherited
toString() String
A string representation of this object.
inherited
validateSearchTerm(String field, dynamic value) → dynamic
inherited

Operators

operator &(Filter other) Filter
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(Filter other) Filter
inherited
operator ~() Filter
inherited