FieldBasedFilter class abstract

This filter is used to filter in fields with any value except null.

Inheritance
Implementers
Available extensions

Constructors

FieldBasedFilter(String field, dynamic value)

Properties

field String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String

Available on Filter, provided by the FilterExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
final

Methods

and(Filter filter) Filter
inherited
apply(Document doc) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Filter
inherited
or(Filter filter) Filter
inherited
toString() String
A string representation of this object.
inherited
validateSearchTerm(String field, dynamic value) → dynamic

Operators

operator &(Filter other) Filter
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(Filter other) Filter
inherited
operator ~() Filter
inherited