Filter class abstract

The base definition for all filters.

Implementers
Available extensions

Constructors

Filter()

Properties

hashCode int
The hash code for this object.
no setteroverride
name String

Available on Filter, provided by the FilterExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(Filter filter) Filter
apply(Document doc) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Filter
or(Filter filter) Filter
toString() String
A string representation of this object.
inherited

Operators

operator &(Filter other) Filter
operator ==(Object other) bool
The equality operator.
override
operator |(Filter other) Filter
operator ~() Filter