CollQLFilter class abstract
- Inheritance
- Implementers
Constructors
Properties
- collectionName ↔ String?
-
getter/setter pair
- CollQLConfig ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- objectFilter ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
and(
Filter filter) → Filter -
apply(
Document doc) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → Filter -
inherited
-
or(
Filter filter) → Filter -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator &(
Filter other) → Filter -
operator ==(
Object other) → bool -
The equality operator.
override
-
operator |(
Filter other) → Filter -
operator ~(
) → Filter -
inherited