CollQLMap<k, v> class

Constructors

CollQLMap()

Properties

hashCode int
The hash code for this object.
no setterinherited
keys Iterable<k>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
entries() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Object? key) → v?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → v?
operator []=(k key, v value) → void