Document class

Constructors

Document()

Properties

hashCode int
The hash code for this object.
no setterinherited
id CollQLId
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String field) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → dynamic