IndexMap class
Constructors
- IndexMap()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ceilingKey(
Comparable comparable) → dynamic -
entries(
) → dynamic -
firstKey(
) → dynamic -
floorKey(
Comparable comparable) → dynamic -
get(
Comparable value) → dynamic -
higherKey(
dynamic ceilingKey) → dynamic -
lastKey(
) → dynamic -
lowerKey(
dynamic lastKey) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited