sizeInfo method

({int bytes, int paths}) sizeInfo()
inherited

Get size information about the document.

paths is the number of paths in the document. bytes is the size of the document in bytes.

Implementation

({int paths, int bytes}) sizeInfo() {
  return (
    paths: internal.length,
    // TODO: tipo especifico de gerenciamento de tamanho?
    bytes: utf8.encode(jsonEncode(internal, toEncodable: _toEncodable,)).length,
  );
}