NotFilter class

Inheritance
Available extensions

Constructors

NotFilter(Filter filter)

Properties

filter Filter
final
hashCode int
The hash code for this object.
no setterinherited
name String

Available on Filter, provided by the FilterExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(Filter filter) Filter
inherited
apply(Document element) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Filter
inherited
or(Filter filter) Filter
inherited
toString() String
A string representation of this object.
override

Operators

operator &(Filter other) Filter
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(Filter other) Filter
inherited
operator ~() Filter
inherited