FilterBuilder class

Constructors

FilterBuilder(FieldName field)

Properties

field FieldName
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

eq(dynamic value) Filter
gt(dynamic value) Filter
gte(dynamic value) Filter
lt(dynamic value) Filter
lte(dynamic value) Filter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notin(List<Comparable> value) Filter
regex(String value) Filter
toString() String
A string representation of this object.
inherited
within(List<Comparable> value) Filter

Operators

operator <(dynamic value) Filter
operator <=(dynamic value) Filter
operator ==(Object other) bool
The equality operator.
inherited
operator >(dynamic value) Filter
operator >=(dynamic value) Filter