ModifierBuilder class

Constructors

ModifierBuilder(FieldName field)

Properties

field FieldName
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addToSet(dynamic value) Modifier
currentDate() Modifier
inc(dynamic value, {dynamic defaultValue = 0}) Modifier
max(dynamic value) Modifier
min(dynamic value) Modifier
mul(dynamic value, {dynamic defaultValue = 0}) Modifier
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop({int? position}) Modifier
pull(bool fnPredicate(dynamic)) Modifier
push(dynamic value, {int? position}) Modifier
rename(FieldName newField) Modifier
set(dynamic value) Modifier
sort() Modifier
toString() String
A string representation of this object.
inherited
unset() Modifier

Operators

operator ==(Object other) bool
The equality operator.
inherited