abstractions/abstractions library
Classes
Mixins
Functions
Exceptions / Errors
- CollQLException
- Base class for all CollQL exceptions.
- CollQLIOException
- Exception thrown when there is an IO error while performing an operation on CollQL database.
- CollQLSecurityException
- Exception thrown when a security violation occurs in CollQL.
- FilterException
- Exception thrown during find operations due to invalid filter expression.
- IndexingException
- Exception thrown when there is an error with indexing in CollQL.
- InvalidIdException
- Exception thrown when an invalid ID is encountered.
- InvalidOperationException
- Exception thrown when an invalid operation is performed.
- MigrationException
- Exception thrown when there is an error during database migration.
- NotIdentifiableException
- Exception thrown when an object cannot be identified.
- ObjectMappingException
- Exception thrown when there is an error mapping an object to a document or vice versa.
- PluginException
- Exception thrown when a CollQL plugin encounters an error.
- TransactionException
- Exception thrown when an error occurs during a transaction.
- UniqueConstraintException
- Exception thrown when a unique constraint is violated.
- ValidationException
- Exception thrown when a validation error occurs.