abstractions/filters library
Classes
- ComparableFilter
- This filter is used to filter in fields that are comparable.
- ComparableInListFilter
- This filter is used to filter in fields that are iterables and contain comparable values.
- FieldBasedFilter
- This filter is used to filter in fields with any value except null.
- Filter
- The base definition for all filters.
- LogicalFilter
- This filter is used to create decision logic with anothers filters.
- SortingAwareFilter
- This filter is used to filter in fields that are sorteable.