LogicalFilter class abstract
This filter is used to create decision logic with anothers filters.
Constructors
-
LogicalFilter(List<
Filter> filters)
Properties
Methods
-
and(
Filter filter) → Filter -
inherited
-
apply(
Document doc) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → Filter -
inherited
-
or(
Filter filter) → Filter -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator &(
Filter other) → Filter -
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
Filter other) → Filter -
inherited
-
operator ~(
) → Filter -
inherited